@@ -1,12 +1,12 @@
 package File::Sticker::Writer::Gif;
-$File::Sticker::Writer::Gif::VERSION = '3.0005';
+$File::Sticker::Writer::Gif::VERSION = '3.0006';
 =head1 NAME
 
 File::Sticker::Writer::Gif - write and standardize meta-data from GIF file
 
 =head1 VERSION
 
-version 3.0005
+version 3.0006
 
 =head1 SYNOPSIS
 
@@ -257,7 +257,26 @@ sub _write_meta {
     my $success = $et->SetNewValue('Comment', $yaml_str);
     if ($success)
     {
-        $et->WriteInfo($filename);
+        # ExifTool has a wicked habit of replacing soft-linked files
+        # with the contents of the file rather than honouring the link.
+        # While using the exiftool script offers -overwrite_original_in_place
+        # to deal with this, the Perl module does not appear to have
+        # such an option available.
+
+        # So the way to get around this is to check if $filename is
+        # a soft link, and if it is, find the real file, and
+        # write to that. (Note that this will not work if the
+        # soft link points to *another* soft link, but I'm
+        # not prepared to go down that rabbit-hole.)
+        if (-l $filename)
+        {
+            my $realfile = readlink $filename;
+            $et->WriteInfo($filename,$realfile);
+        }
+        else
+        {
+            $et->WriteInfo($filename);
+        }
     }
 
 } # _write_meta
